@@ -12,6 +12,8 @@ import (
 
 // ApiChange represnts a change in the Paths Section of an OpenAPI spec
 type ApiChange struct {
+	CommonChange
+
 	Id          string
 	Args        []any
 	Comment     string
@@ -28,19 +30,37 @@ type ApiChange struct {
 	SourceColumnEnd int
 }
 
-func NewApiChange(id string, level Level, args []any, comment string, operationsSources *diff.OperationsSourcesMap, operation *openapi3.Operation, method, path string) ApiChange {
+func NewApiChange(id string, config *Config, args []any, comment string, operationsSources *diff.OperationsSourcesMap, operation *openapi3.Operation, method, path string) ApiChange {
 	return ApiChange{
 		Id:          id,
-		Level:       level,
+		Level:       config.getLogLevel(id),
 		Args:        args,
 		Comment:     comment,
 		OperationId: operation.OperationID,
 		Operation:   method,
 		Path:        path,
 		Source:      load.NewSource((*operationsSources)[operation]),
+		CommonChange: CommonChange{
+			Attributes: getAttributes(config, operation),
+		},
 	}
 }
 
+func getAttributes(config *Config, operation *openapi3.Operation) map[string]any {
+	result := map[string]any{}
+	for _, tag := range config.Attributes {
+		if val, ok := operation.Extensions[tag]; ok {
+			result[tag] = val
+		}
+	}
+
+	if len(result) == 0 {
+		return nil
+	}
+
+	return result
+}
+
 func (c ApiChange) GetSection() string {
 	return "paths"
 }
