@@ -6,6 +6,8 @@ import (
 )
 
 type ChangelogFlags struct {
+	CommonFlags
+
 	base                  *load.Source
 	revision              *load.Source
 	composed              bool
@@ -30,6 +32,7 @@ type ChangelogFlags struct {
 	deprecationDaysBeta   uint
 	deprecationDaysStable uint
 	color                 string
+	severityLevelsFile    string
 }
 
 func (flags *ChangelogFlags) toConfig() *diff.Config {
@@ -117,6 +120,10 @@ func (flags *ChangelogFlags) getAsymmetric() bool {
 	return false
 }
 
+func (flags *ChangelogFlags) getSeverityLevelsFile() string {
+	return flags.severityLevelsFile
+}
+
 func (flags *ChangelogFlags) setBase(source *load.Source) {
 	flags.base = source
 }
@@ -208,3 +215,7 @@ func (flags *ChangelogFlags) refDeprecationDaysStable() *uint {
 func (flags *ChangelogFlags) refColor() *string {
 	return &flags.color
 }
+
+func (flags *ChangelogFlags) refSeverityLevelsFile() *string {
+	return &flags.severityLevelsFile
+}
