@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"io"
 	"sort"
-	"strings"
 
 	"github.com/spf13/cobra"
 	"github.com/tufin/oasdiff/checker"
@@ -20,7 +19,6 @@ type ChecksFlags struct {
 	format   string
 	severity []string
 	tags     []string
-	required string
 }
 
 func getChecksCmd() *cobra.Command {
@@ -47,28 +45,14 @@ func getChecksCmd() *cobra.Command {
 
 	enumWithOptions(&cmd, newEnumValue(localizations.GetSupportedLanguages(), localizations.LangDefault, &flags.lang), "lang", "l", "language for localized output")
 	enumWithOptions(&cmd, newEnumValue(formatters.SupportedFormatsByContentType(formatters.OutputChecks), string(formatters.FormatText), &flags.format), "format", "f", "output format")
-	enumWithOptions(&cmd, newEnumSliceValue([]string{"info", "warn", "error"}, nil, &flags.severity), "severity", "s", "list of severities to include (experimental)")
-	cmd.PersistentFlags().StringSliceVarP(&flags.tags, "tags", "t", []string{}, "list of tags to include, eg. parameter, request (experimental)")
-	enumWithOptions(&cmd, newEnumValue([]string{"true", "false", "all"}, "all", &flags.required), "required", "r", "filter by required / optional")
+	enumWithOptions(&cmd, newEnumSliceValue([]string{"info", "warn", "error"}, nil, &flags.severity), "severity", "s", "include only checks with any of specified severities")
+	enumWithOptions(&cmd, newEnumSliceValue(getAllTags(), nil, &flags.tags), "tags", "t", "include only checks with all specified tags")
 
 	return &cmd
 }
 
 func runChecks(stdout io.Writer, flags ChecksFlags) *ReturnError {
-	return outputChecks(stdout, flags, getRules(flags.required))
-}
-
-func getRules(required string) []checker.BackwardCompatibilityRule {
-	switch required {
-	case "all":
-		return checker.GetAllRules()
-	case "false":
-		return checker.GetOptionalRules()
-	case "true":
-		return checker.GetRequiredRules()
-	}
-
-	return nil
+	return outputChecks(stdout, flags, checker.GetAllRules())
 }
 
 func outputChecks(stdout io.Writer, flags ChecksFlags, rules []checker.BackwardCompatibilityRule) *ReturnError {
@@ -96,25 +80,15 @@ func outputChecks(stdout io.Writer, flags ChecksFlags, rules []checker.BackwardC
 			}
 		}
 
-		// tags (experimental, the string contains approach is not very robust)
-		if len(flags.tags) > 0 {
-			match := false
-			for _, tag := range flags.tags {
-				if strings.Contains(rule.Id, tag) {
-					match = true
-				}
-			}
-
-			if !match {
-				continue
-			}
+		// tags
+		if !matchTags(flags.tags, rule) {
+			continue
 		}
 
 		checks = append(checks, formatters.Check{
 			Id:          rule.Id,
 			Level:       rule.Level.String(),
 			Description: rule.Description,
-			Required:    rule.Required,
 		})
 	}
 
