@@ -26,6 +26,8 @@ type Flags interface {
 	getLevel() string
 	getFailOnDiff() bool
 	getAsymmetric() bool
+	getSeverityLevelsFile() string
+	getAttributes() []string
 
 	setBase(source *load.Source)
 	setRevision(source *load.Source)
@@ -52,4 +54,18 @@ type Flags interface {
 	refDeprecationDaysBeta() *uint
 	refDeprecationDaysStable() *uint
 	refColor() *string
+	refSeverityLevelsFile() *string
+	refAttributes() *[]string
+}
+
+type CommonFlags struct {
+	attributes []string
+}
+
+func (flags *CommonFlags) getAttributes() []string {
+	return flags.attributes
+}
+
+func (flags *CommonFlags) refAttributes() *[]string {
+	return &flags.attributes
 }
