@@ -247,6 +247,10 @@ func Test_Changelog(t *testing.T) {
 	require.Len(t, cl, 1)
 }
 
+func Test_ChangelogWithAttributes(t *testing.T) {
+	require.Zero(t, internal.Run(cmdToArgs("oasdiff changelog ../data/openapi-test1.yaml ../data/openapi-test3.yaml --attributes x-beta,x-extension-test  -f yaml"), io.Discard, io.Discard))
+}
+
 func Test_BreakingChangesChangelogOptionalCheckersAreInfoLevel(t *testing.T) {
 	var stdout bytes.Buffer
 	require.Zero(t, internal.Run(cmdToArgs("oasdiff changelog ../data/run_test/changelog_include_checks_base.yaml ../data/run_test/changelog_include_checks_revision.yaml --format json"), &stdout, io.Discard))
@@ -303,7 +307,7 @@ func Test_FlattenCmdInvalid(t *testing.T) {
 }
 
 func Test_Checks(t *testing.T) {
-	require.Zero(t, internal.Run(cmdToArgs("oasdiff checks -l ru"), io.Discard, io.Discard))
+	require.Zero(t, internal.Run(cmdToArgs("oasdiff checks -l ru --tags decrease,parameters --severity info,warn,error"), io.Discard, io.Discard))
 }
 
 func Test_Color(t *testing.T) {
@@ -326,3 +330,11 @@ func Test_InvalidEnumValue(t *testing.T) {
 	require.Equal(t, `Error: invalid argument "xxx" for "-e, --exclude-elements" flag: xxx is not one of the allowed values: description, endpoints, examples, extensions, summary, or title
 `, stderr.String())
 }
+
+func Test_CustomSeverityLevels(t *testing.T) {
+	require.Zero(t, internal.Run(cmdToArgs("oasdiff changelog ../data/openapi-test1.yaml ../data/openapi-test3.yaml --severity-levels ../data/severity-levels.txt"), io.Discard, io.Discard))
+}
+
+func Test_CustomSeverityLevelsInvalidFile(t *testing.T) {
+	require.Equal(t, 106, internal.Run(cmdToArgs("oasdiff changelog ../data/openapi-test1.yaml ../data/openapi-test3.yaml --severity-levels ../data/invalid.txt"), io.Discard, io.Discard))
+}
